@@ -19,6 +19,7 @@ import re
 import sys
 from typing import Any, Dict, Iterable, List, Optional, Tuple
 import unittest
+from unittest import mock
 
 from docutils import nodes
 from docutils.parsers.rst import Directive
@@ -476,7 +477,11 @@ class ScannerTestCase(unittest.TestCase):
         # section: default optionals
         program, options, group = sections[1]
         self.assertEqual([], program)
-        self.assertEqual("optional arguments", group.title)
+        # See https://github.com/sphinx-contrib/autoprogram/issues/24
+        if sys.version_info >= (3, 10):
+            self.assertEqual('options', group.title)
+        else:
+            self.assertEqual('optional arguments', group.title)
         self.assertEqual(None, group.description)
         self.assertEqual(2, len(options))
         self.assertEqual(
@@ -534,7 +539,7 @@ class AutoprogramDirectiveTestCase(unittest.TestCase):
             0,
             ".. autoprogram:: cli:parser\n   :prog: cli.py\n",
             None,
-            None,
+            mock.Mock(),
         )
 
     def tearDown(self) -> None:
